#!/opt/VRTSperl/bin/perl -w
#------------------------------------------------------------------
# $Copyright: Copyright (c) 2013 Symantec Corporation.
# All rights reserved.
#
# THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION AND TRADE SECRETS OF
# SYMANTEC CORPORATION.  USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED
# WITHOUT THE PRIOR EXPRESS WRITTEN PERMISSION OF SYMANTEC CORPORATION.
#
# The Licensed Software and Documentation are deemed to be commercial
# computer software as defined in FAR 12.212 and subject to restricted
# rights as defined in FAR Section 52.227-19 "Commercial Computer
# Software - Restricted Rights" and DFARS 227.7202, "Rights in
# Commercial Computer Software or Commercial Computer Software
# Documentation", as applicable, and any successor regulations. Any use,
# modification, reproduction release, performance, display or disclosure
# of the Licensed Software and Documentation by the U.S. Government
# shall be solely in accordance with the terms of this Agreement.  $
#
# $Header: /project/isv-agent/VProAgents/WebSphere/update.pl,v 1.4 2010/03/08 14:21:11 rkumar Exp $
#
# $sAuthor: $
#
# $Date: 2010/03/08 14:21:11 $
# $Revision: 1.4 $
#------------------------------------------------------------------

use strict;
use POSIX;
use Getopt::Std;
use Fcntl;
use File::Path qw ( mkpath );

use constant HARES     => "/opt/VRTSvcs/bin/hares";
use constant HATYPE    => "/opt/VRTSvcs/bin/hatype";
use constant HACONF    => "/opt/VRTSvcs/bin/haconf";
use constant HACF      => "/opt/VRTSvcs/bin/hacf";
use constant HACLUS    => "/opt/VRTSvcs/bin/haclus";
use constant MAINCFLOC => "/etc/VRTSvcs/conf/config";

sub usage {
  warn << "EOF";

  Update:- Update the Old Agent Type with New Agent type, provided all the attributes of both the types are same. 
  
  Usage:
  
  $0 -o <OldType> -n <NewType> 

  -o  --oldType   The type of which the resources are present on system.
  -n  --newType   The type to which the old type has to be changed.
  -h  --help      Help (this message)
EOF

  exit 1;
}

my ( $sCommand, $sCmdOut, $iExitCode, $sMainCmdFile, $sAttribute, $sRestoreMsg,
     $sOptStr, $SystemList, $sRmPkg, $sTypeFile, $sRes, $sLine, $bSuccessFlag, 
     $sTempCmdFile, $sLogDir, $sNewArgList, $iPid, $sKey, @lsRes, @lsArgList, 
     @lsDepList, %hsOpts, %hsResAttr ) = ();

&usage () unless scalar @ARGV;

my %hsSupported = ( '--oldType' => '-o', '--newType' => '-n',
                    '--help'    => '-h' );

#-----------------------
# Collect command line..
#-----------------------
$sOptStr = 'o:n:h';

grep {                      # Filter..
  $hsSupported { $_ }    && # Defined..
  s/$_/$hsSupported{$_}/ || # Then substitute..
  1                         # Else, continue..
} @ARGV;                    # From what's been passed..

&getopts ( $sOptStr, \%hsOpts ) || &usage ();


if ( $hsOpts { h } ) {
  &usage();
}

if ( ! $hsOpts { o }  ) {
  &usage();
}
if ( ! $hsOpts { n }  ) {
  &usage();
}

my ( $sOldType,  $sNewType ) = ( $hsOpts { o }, $hsOpts { n } ) ;

if ( ! ( $sOldType =~ /\S+/ ) || 
     ! ( $sNewType =~ /\S+/ ) ) {
   &usage;
}

#----------------------------------
# Remove the log directory if exist
#----------------------------------
chomp ( $sNewType );
$sLogDir = "/var/VRTSvcs/log/tmp/${sNewType}_$$";

if ( -e $sLogDir ) {
  $sCommand = "/bin/rm -rf $sLogDir > /dev/null 2>&1";
  system ( $sCommand );
  if( $iExitCode = $? >> 8 ) {
    warn "Failed to remove existing log Directory [$sLogDir]\n";
    exit 1;
  }  
}

#-------------------
# Create the Log Dir
#-------------------
if ( ! mkpath ( $sLogDir, 0, 0700 ) ) {
  warn "Failed to make log directory [$sLogDir]: $!\n";
  exit 1;   
}

#--------------------------------------
# Open the log file for printing output
#--------------------------------------

sysopen ( LOG, "$sLogDir/update.log",
          O_WRONLY|O_SYNC|O_CREAT|O_TRUNC, 0640 ) ||
die "Failed to create and open file  [$sLogDir/update.log]: $!\n";

#-------------------------------
# Dump the current configuration
#-------------------------------
$sCommand = HACONF . " -dump > /dev/null 2>&1";
system ( $sCommand );

if ( $iExitCode = $? >> 8 ) {
  warn "Failed to dump the current configuration in main.cf\n";
  print LOG "[Failure] Failed to dump the current configuration in main.cf\n";
  print "For more details check the log file [$sLogDir/update.log]\n";
  close ( LOG );
  exit 1;
}
else {
  print LOG "[Success] Current configuration is dumped in main.cf\n";
}

#---------------------------------
# Check old type is present or not
#---------------------------------
$sCommand =  HATYPE . " -display $sOldType";
$sCmdOut = `$sCommand 2>&1`;

if ( $iExitCode = $? >> 8 ) {
  if ( $sCmdOut =~ /Type does not exist/ ) {
    warn "The Agent Type [$sOldType] is not imported in the cluster\n";
    print LOG "[Failure] The Agent Type [$sOldType] is not imported in the cluster\n";
    print "For more details check the log file [$sLogDir/update.log]\n";
    close ( LOG );
    exit 1;
  }
  else {
    warn "Not able to execute [hatype] command on this node\n";
    print LOG "[Failure] Not able to execute [hatype] command on this node\n";
    print LOG "Check whether vcs is running or not. If not start vcs and try the update script again\n";
    print "For more details check the log file [$sLogDir/update.log]\n";
    exit 1;
  }
}  
else {
  print LOG "[Success] Old Type [$sOldType] exists check passed\n";
} 

#-----------------------------------------
# Confirm New Type is not already imported
#-----------------------------------------
$sCommand =  HATYPE . " -display $sNewType";
$iPid = open ( CMD, "$sCommand 2>&1| ");
if( defined $iPid && $iPid > 1 ) {
  $sCmdOut = <CMD>;
  if ( ! ( $sCmdOut =~ /Type does not exist/ ) ) {
    warn "The agent type [$sNewType] is already imported in the cluster\n";
    print LOG "[Failure]The agent type [$sNewType] is already imported in the cluster\n";
    print LOG "Could not replace [$sOldType] to [$sNewType]\n";
    print "For more details check the log file [$sLogDir/update.log]\n";
    close ( LOG );
    exit 1;
  }
  else {
    print LOG "[Success] New Type [$sNewType] is not imported\n";
  }
}
else {
  warn "Not able to execute [hatype] command on this node\n";
  print LOG "[Failure] Not able to execute [hatype] command on this node\n";
  print LOG "Check whether vcs is running or not. If not start vcs and try the update script again\n";
  print "For more details check the log file [$sLogDir/update.log]\n";
  close ( LOG );
  exit 1;
}

$sCommand = HATYPE . " -value $sOldType ArgList";
$sCmdOut = `$sCommand 2>&1`;
if ( $iExitCode = $? >> 8 ) {
  warn "Not able to get the ArgList of old type\n";
  print LOG "[Failure] Not able to get the ArgList of old type using command [$sCommand]\n";
  print "For more details check the log file [$sLogDir/update.log]\n";
  close ( LOG );
  exit 1;
}
else {
  print LOG "[Success] Get the ArgList of old type\n";
}
@lsArgList = ( $sCmdOut =~ /(\S+)/g );

if ( -e ( $sTypeFile = "/etc/VRTSagents/ha/conf/${sNewType}/${sNewType}Types.cf" )  ||
     -e ( $sTypeFile = "/etc/VRTSagents/ha/conf/${sNewType}/${sNewType}Types50.cf" ) ||
     -e ( $sTypeFile = "/etc/VRTSagents/ha/conf/${sNewType}/${sNewType}Types51.cf" ) ||
     -e ( $sTypeFile = "/etc/VRTSvcs/conf/sample_${sNewType}/${sNewType}Types.cf" ) ) {
  if ( ! open ( TYPEFILDES, $sTypeFile ) ) {
    warn "Filed to open Agent type file [$sTypeFile] for read\n";
    print LOG "[Failure] Failed to open Agent Type File ".
               "[$sTypeFile] for read\n";
    print "For more details check the log file [$sLogDir/update.log]\n";
    close ( LOG );
    exit 1;
  }
  else {
    print LOG "[Success] Agent Type File[$sTypeFile] is opened for read\n";
  }
}
else {
  warn "Agent type file for [$sNewType] does not exist\n";
  print LOG "[Failure] Agent Type File for [$sNewType] does not exist, ". 
            "Re-install the latest agent package\n";
  print "For more details check the log file [$sLogDir/update.log]\n";
  close ( LOG );
  exit 1;
}

while ( $sLine = <TYPEFILDES> ) {
  if ( $sLine =~ m/.*ArgList.*=\s+\{\s+(.*)\}/ ) {
    $sNewArgList = $1 if $1;
  }
}
close ( TYPEFILDES );

if ( defined $sNewArgList && 
     ( $sNewArgList =~ s/\s*,\s*/ /g ) && 
     ( $sCmdOut =~ s/\s+/ /g ) &&
     $sNewArgList =~ /^$sCmdOut$/ ) {
  print LOG "[Success]The ArgList of old type [$sOldType] is same as ".
            "The ArgList of new type [$sNewType]\n";
}
else {
  warn "The old type [$sOldType] ArgList [$sCmdOut] is different from
        The new type [$sNewType] ArgList [$sNewArgList]\n";
  print LOG "[Failure] The old type [$sOldType] ArgList [$sCmdOut] is different from ".
            "The new type [$sNewType] ArgList [$sNewArgList]\n";
  print "For more details check the log file [$sLogDir/update.log]\n";
  close ( LOG );
  exit 1;
}
print "\nAre you sure to update [$sOldType] Type to [$sNewType] Type (y/n):";
my $sConfirm = <>;
if ( ! ( $sConfirm =~ /^(y|Y)$/ ) ){
  close ( LOG );
  exit 1;
}
#---------------------------
# Take the backup of main.cf
#---------------------------
$sCommand = "/bin/cp -f /etc/VRTSvcs/conf/config/main.cf $sLogDir/main.cf.before_update > /dev/null 2>&1";
system ( $sCommand );

if ( $iExitCode = $? >> 8 ) {
  warn "Failed to backup the current main.cf\n";
  print LOG "[Failure] Failed to backup the current main.cf\n";
  print "For more details check the log file [$sLogDir/update.log]\n";
  close ( LOG );
  exit 1;
}
else {
  print LOG "[Success] The backup of main.cf before update is ". 
            "present at [$sLogDir/main.cf.before_update]\n";
}

$sRestoreMsg = "\nThe backup of main.cf before the execution of this 
                update script is avialable at [$sLogDir/main.cf.before_update].
                You can restore your configuration using this file.\n";

$sCommand = HACF . " -cftocmd " . MAINCFLOC .  " -dest $sLogDir > /dev/null 2>&1";
system ( $sCommand );

if ( $iExitCode = $? >> 8 ) {
  warn " Failed to create main.cmd from main.cf\n ";
  print LOG "[Failure] Failed to create main.cmd from main.cf\n";
  print "For more details check the log file [$sLogDir/update.log]\n";
  close ( LOG );
  exit 1;
}
else {
  print LOG "[Success] main.cmd is generated from main.cf\n";
}

#-------------------------------------
# Obtain the resource list of Old Type
#-------------------------------------
$sCommand = HATYPE . " -resources $sOldType";
$sCmdOut = `$sCommand 2>&1`;
@lsRes = ( $sCmdOut =~ m/(\S+)\n/g );

#----------------------------------------
# Filter Type specific data from main.cmd
#----------------------------------------

$sMainCmdFile = "$sLogDir/main.cmd";
$sTempCmdFile = "$sLogDir/main_temp.cmd";

if ( ! open ( FILDES, $sMainCmdFile ) ) {
  warn "Filed to open created file [$sMainCmdFile] for read\n";
  print LOG "[Failure] Failed to open created File". 
            "[$sMainCmdFile] for read\n";
  print "For more details check the log file [$sLogDir/update.log]\n";
  close ( LOG );
  exit 1;
}
else {
  print LOG "[Success] main.cmd is opened for read\n";
}

if ( ! sysopen ( TEMPFILDES, $sTempCmdFile,
          O_WRONLY|O_CREAT|O_TRUNC, 0755 ) ) {
  warn "Failed to create and open file [$sTempCmdFile]: $!\n";
  print LOG "[Failure] Failed to create and open file [$sTempCmdFile]";
  print "For more details check the log file [$sLogDir/update.log]\n";
  close ( LOG );
  exit 1;
}
else {
  print LOG "[Success] Temprory File [$sTempCmdFile] is created and opened ".
            "for filtering Type specific data\n";
}

print TEMPFILDES "#!/bin/sh\n";
print TEMPFILDES "PATH=/opt/VRTSvcs/bin:\$PATH\nexport PATH\n";
$sLine = ();
while ( $sLine = <FILDES> ) { 
  if ( ( ( $sLine =~ m/\b$sOldType\b/g ) && 
         ( $sLine =~ m/\b(hatype|haattr)\b/ ) ) &&
       ! ( $sLine =~ m/hares/ ) ) {
    if ( $sLine =~ m/\bSourceFile\b/ ) {
      $sLine =~ s/$sOldType/$sNewType/g;
    }
    else {
      $sLine =~ s/\b$sOldType\b/$sNewType/g;
    }
    print TEMPFILDES $sLine;
  }
}

close ( TEMPFILDES ) ||
die "Failed to close [$sTempCmdFile] after write: $!\n";

close ( FILDES ) ||
die "Failed to close [$sMainCmdFile] after read: $!\n";

$sCommand = HACLUS . " -value ReadOnly";
$sCmdOut = `$sCommand 2>&1`;
chomp ( $sCmdOut );

if ( 1 == $sCmdOut ) {
  $sCommand = HACONF . " -makerw > /dev/null 2>&1";
  system ( $sCommand );
  if ( $iExitCode = $? >> 8 ) {
    warn "Failed to configure the cluster for read and write\n";
    print LOG "[Failure] Failed to configure the cluster for read/write\n";
    print " For more details check the log file [$sLogDir/update.log]\n";
    close ( LOG );
    exit 1;
  }
  else {
     print LOG "[Success] The cluster is configured for read/write\n";
  }
}

print LOG "Updating agent type file on this node\n";
if ( defined $sTypeFile && -e $sTypeFile ) {
  $sCommand = "/bin/cp -f $sTypeFile /etc/VRTSvcs/conf/config/. > /dev/null 2>&1";
  if ( $iExitCode = $? >> 8 ) {
    warn "Not able to copy Agent Type file to [/etc/VRTSvcs/conf/config]\n";
    print LOG "[Failure] Not able to copy Agent Type file to [/etc/VRTSvcs/conf/config]\n";
    print "For more details check the log file [$sLogDir/update.log]\n";
    exit 1;
  }
  else {
    print LOG "[Success] Executed the command [$sCommand]\n";
  }
}

#------------------------------
# Execute the filtered main.cmd
#------------------------------
system ( "cd $sLogDir;./main_temp.cmd" );
if ( $iExitCode = $? >> 8 ) {
  warn "Failed to add resource type [$sNewType]\n";
  print LOG "[Failure] Failed to add resource type [$sNewType]\n";
  print "For more details check the log file [$sLogDir/update.log] $sRestoreMsg\n";
  close ( LOG );
  exit 1;
}
else {
 print LOG "[Success] The new resource type is added\n";
}

#-------------------------------------------------
# Change all the resources of Old Type to New Type
#-------------------------------------------------
$bSuccessFlag = 0;
foreach $sRes ( @lsRes ) {
  %hsResAttr = ();
  $sCommand = HARES . " -value $sRes Group";
  $sCmdOut = `$sCommand 2>&1`;
  if ( $iExitCode = $? >> 8 ) {
    warn "Not able to run the command [$sCommand]\n";
    print LOG "[Failure] Failed to execute the command [$sCommand]\n";
    print "For more details check the log file [$sLogDir/update.log] $sRestoreMsg\n";
    exit 1;
  }
  else {
    print LOG "[Success] Executed the command [$sCommand]\n";
  }
  $hsResAttr{ Group } = $sCmdOut ;
  push ( @lsArgList , "Critical", "Enabled" );
  
  foreach $sAttribute ( @lsArgList ) {
    if ( $sAttribute =~ m/State/ ) {
      next;
    }
    $sCommand = HARES . " -display $sRes -attribute $sAttribute";
    my @lsAttributeVal = `$sCommand 2>&1`;
    if ( $iExitCode = $? >> 8 ) {
      warn "Not able to run the command [$sCommand]\n";
      print LOG "[Failure] Failed to execute the command [$sCommand]\n";
      print "For more details check the log file [$sLogDir/update.log] $sRestoreMsg\n";
      exit 1;
    }
    else {
      print LOG "[Success] Executed the command [$sCommand]\n";
    }
    shift @lsAttributeVal;
    my %hsSystemAttrVal = ();
    foreach ( @lsAttributeVal ) {
       /(\S+)\s+(\S+)\s+(\S+)\s+(.*)$/;
       if ( defined $4 ) {
         $hsSystemAttrVal{ $3 } = $4;
       }
       else {
         $hsSystemAttrVal{ $3 } = "";
       }
    }
    $hsResAttr{ $sAttribute } = \%hsSystemAttrVal;
  }

  #-----------------------------------------
  # Get resource dependency for the resource
  #-----------------------------------------
  $sCommand = HARES . " -dep $sRes";
  @lsDepList = ();
  $iPid = open ( CMD, "$sCommand 2>&1 | ");
  if( defined $iPid && $iPid > 1 ) {
    $sCmdOut = <CMD>;
    if ( ! ( $sCmdOut =~ /No Resource dependencies are configured/ ) ) {
      while ( <CMD> ) {
        push ( @lsDepList, $_ );
      }
    }
    print LOG "[Success] Executed the command [$sCommand] with Output[@lsDepList]\n";
  }
  else {
    warn "Not able to run the command [$sCommand]\n";
    print LOG "[Failure] Failed to execute the command [$sCommand]\n";
    print "For more details check the log file [$sLogDir/update.log] $sRestoreMsg\n";
    exit 1;
  }

  $sCommand = HARES . " -delete $sRes > /dev/null 2>&1";
  system ( $sCommand );

  if ( $iExitCode = $? >> 8 ) {
    print LOG "[Failure]  Failed to delete resource [$sRes] of old type\n";
    print LOG "[Failure] Failed to delete resource [$sRes] of old type\n";
    print "For more details check the log file [$sLogDir/update.log] $sRestoreMsg\n";
    exit 1;
  }
  else {
    print LOG "[Success] Delete resource [$sRes] of old type\n";
  }
  chomp ( $hsResAttr{ Group } );
  $sCommand = HARES . " -add $sRes $sNewType $hsResAttr{ Group }" . "  >/dev/null 2>&1";
  system ( $sCommand );

  if ( $iExitCode = $? >> 8 ) {
    print LOG "[Failure] Failed to add the resource [$sRes] of new type\n";
    print LOG "[Failure] Failed to add  resource [$sRes] of new type\n";
    print "For more details check the log file [$sLogDir/update.log] $sRestoreMsg\n";
    exit 1;
  }
  else {
    print LOG "[Success] Add resource [$sRes] of new type\n";
  }
  foreach $sAttribute ( @lsArgList ) {
    if ( $sAttribute =~ /(State|Group)/ ) {
      next;
    }
    my $href = $hsResAttr{ $sAttribute };
    my $bGlobalFlag = 0;
    foreach $sKey ( keys %$href    ) {
      $sCommand = ();
      if ( $sKey =~ /global/ && 
           ( $bGlobalFlag = 1 ) &&
           $hsResAttr{ $sAttribute }{$sKey} =~ /\S+/ ) {
        chomp( $hsResAttr{ $sAttribute }{ $sKey } );
        if ( $hsResAttr{ $sAttribute }{ $sKey } =~ m/\-/ ) {
          $sCommand = HARES . " -modify $sRes $sAttribute \"\%$hsResAttr{ $sAttribute }{ $sKey }\" > /dev/null 2>&1";
        }
        elsif ( $hsResAttr{ $sAttribute }{ $sKey } =~ m/\s+/ ) {
          $sCommand = HARES . " -modify $sRes $sAttribute \"$hsResAttr{ $sAttribute }{ $sKey }\" > /dev/null 2>&1";
        }
        else {
          $sCommand = HARES . " -modify $sRes $sAttribute $hsResAttr{ $sAttribute }{ $sKey } > /dev/null 2>&1";
        }
      }
      elsif ( $hsResAttr{ $sAttribute }{ $sKey } =~ /\S+/ ) {
        chomp( $hsResAttr{ $sAttribute }{ $sKey } );
        if ( $hsResAttr{ $sAttribute }{ $sKey } =~ m/\-/ ) {
          $sCommand = HARES . " -modify $sRes $sAttribute \"\%$hsResAttr{ $sAttribute }{ $sKey }\" -sys $sKey > /dev/null 2>&1";
        }
        elsif ( $hsResAttr{ $sAttribute }{ $sKey } =~ m/\s+/ ) {
          $sCommand = HARES . " -modify $sRes $sAttribute \"$hsResAttr{ $sAttribute }{ $sKey }\" -sys $sKey > /dev/null 2>&1";
        }
        else {
          $sCommand = HARES . " -modify $sRes $sAttribute $hsResAttr{ $sAttribute }{ $sKey } -sys $sKey > /dev/null 2>&1";
        }
        
      }
              
      if ( !  $bGlobalFlag ) {
        my $sLocalCommand = HARES . " -local $sRes $sAttribute > /dev/null 2>&1";
        system ( $sLocalCommand );
        if ( $iExitCode = $? >> 8 ) {
          print LOG "[Failure] Failed to make the attribute [$sAttribute] local for resource[$sRes]\n";
          $bSuccessFlag = 1;
        }
        else {
          print LOG "[Success] Resource modification command [$sLocalCommand] executed for resource [$sRes]\n";
        }
        $bGlobalFlag = 1;
      }
      if ( defined $sCommand ) {
        system ( $sCommand );
        if ( $iExitCode = $? >> 8 ) {
          print LOG "[Failure] Failed to modify attribute [$sAttribute] resource[$sRes] with command [$sCommand]\n";
          $bSuccessFlag = 1;
        }
        else {
          print LOG "[Success] Resource modification command [$sCommand] executed for resource [$sRes]\n";
        }
      }
    }
  }
  if ( scalar @lsDepList ) {
    foreach my $sDep ( @lsDepList ) {
      $sDep =~ /(\S+)\s+(\S+)\s+(\S+)/;
      if ( defined $3 ) {
        $sCommand = HARES . " -link $2 $3 > /dev/null 2>&1";
        system ( $sCommand );
        if ( $iExitCode = $? >> 8 ) {
          print LOG "[Failure] Failed to link resource [$2] and resource [$3] \n";
          $bSuccessFlag = 1;
        }
        else {
          print LOG "[Success] Resource link command [$sCommand] executed for resource [$2] and [$1]\n";
        }
      }
      else {
        print LOG "[Failure] Unable to get parent and child for dependency link, for resource [$sRes]\n";
      }
    }
  } 
}

$sCommand = HATYPE . " -delete $sOldType > /dev/null 2>&1";
system ( $sCommand );

if ( $iExitCode = $? >> 8 ) {
  print LOG "[Failure] Failed to delete old agent type [$sOldType] from the cluster\n";
  $bSuccessFlag = 1;
}
else {
  print LOG "[Success] Old agent type [$sOldType] deleted\n";
  print "\nOld Agent type [$sOldType]  has been deleted \n";
}

if ( 0 == $bSuccessFlag ) {

  #-------------------------------
  # Dump the changed configuration
  #-------------------------------
  $sCommand = HACONF . " -dump > /dev/null 2>&1";
  system ( $sCommand );

  if ( $iExitCode = $? >> 8 ) {
    warn "Failed to dump the changed configuration in main.cf\n";
    print LOG "[Failure] Failed to dump the changed configuration in main.cf\n";
    print "For more details check the log file [$sLogDir/update.log]\n";
    close ( LOG );
    exit 1;
  }
  else {
    print LOG "[Success] Changed configuration is dumped in main.cf\n";
  }
  print "The old agent type[ $sOldType ] is successfully replaced by new agent type [$sNewType]\n";
  print "For more details check the log file [$sLogDir/update.log]\n";
  close ( LOG );
  exit 0;
}

warn "The update process did not completed successfully.\n";
warn "For more details check the log file [$sLogDir/update.log] $sRestoreMsg\n";
close ( LOG );
exit 1;
